@@ -16,6 +16,14 @@
 
   ddrlib functions:
 
+    ddr_info_msg(message)
+    ddr_debug_msg(debug_flag, message)
+    ddr_warning_msg(message)
+    ddr_error_msg(message)
+    ddr_write_to_file(data: str, target_dir: str, filename: str, mode: str = "w")
+    ddr_delete_file(target_dir: str, filename: str)
+    ddr_log_data(data: str, target_dir: str,)
+    ddr_save_output(data: str, target_dir: str)
     ddr_get_truth(data, relate, value, debug_flag)
     ddr_nc_notify(device, access_type, triggers, return_response, debug_flag=False)
     ddr_show_trigger(device, access_type, genie_parser_name, show_template, pcount, par1, par2, par3, parameter, relate, test_value, interval, retries, debug_flag=False)
@@ -28,7 +36,6 @@
     ddr_write_to_syslog(syslog_message, debug_flag=False)
     ddr_cli_command(device, access_type, command, return_response, timestamp, debug_flag=False)
     ddr_wait(seconds, debug_flag=False)
-    ddr_cli_command(device, access_type, command, return_response, timestamp, debug_flag=False)
     ddr_cli_configure(device, access_type, command, return_response, timestamp, debug_flag=False)
     ddr_trigger_notify(device, triggers, debug_flag=False)
     ddr_decode_btrace_log(device, access_type, show_template, pcount, par1, par2, par3, match_string, log_path, debug_flag=False)
@@ -38,7 +45,7 @@
   Revision History
     * 0.1.43 - 7.1.22 - petervh - Updated ddr_decode_btrace_log for changes in btrace logging
     * 1.0.04 - 9.6.22 - petervh - Update documentation, add ddr_ prefix to helper functions
-
+    * 1.0.05 - 9.16.2 - petervh - Include helper functions for logging and file operations
 '''
 import pexpect
 import re
@@ -1051,6 +1058,7 @@ def ddr_trigger_notify(device, triggers, debug_flag=False):
     except Exception as e:
         notify_conn.close_session()
         ddr_error_msg(f"ddr_trigger_notify Exception: {str(e)}")
+        ddr_error_msg("Verify that passwordless NETCONF access enabled in guestshell: \n iosp_client -c 'netconf-yang' -f netconf_enable guestshell 830 \n iosp_client -f netconf_enable_passwordless guestshell guestshell")
         raise
 
     notify_conn.close_session()
